/*
** events.h -	header for events.c
**
** Keith Zaback (krz@wcug.wwu.edu) Apr 98
*/

#ifndef INC_EVENTS_H
#define INC_EVENTS_H

/* internal events */
#define ETYPE_INVALID		0	/* bad type */
#define ETYPE_LIST_HEAD		1024	/* head of the list */

/* the special event */
#define ETYPE_SPECAL		2048

/* events that are handled easily */
#define ETYPE_CACHE_MAINT	1	/* cache maintence */
#define ETYPE_FLCP_TIMEOUT	2
#define ETYPE_LCP_IGNORE	3
#define ETYPE_PERIODIC_STATS	4
#define ETYPE_RESET_CHECK	5
#define ETYPE_UDP_MAINT		6	/* udp interface maintence */

typedef struct stEVENTLIST {
	struct timeval		alarm;			/* when to do this event */
	int			type;			/* event type */
	void			(*handler)(void *, int);	/* handler function */
	void			*user; 			/* user data */
	int			respawn;		/* respawn timer */
	struct stEVENTLIST	*next;			/* the link */
} EVENTLIST;


/* protos */
void		event_dump(EVENTLIST *elist);
int		remove_events(EVENTLIST *elist, int type, void (*handler)(void *, int));
int		do_events(EVENTLIST *elist, struct timeval *now);
int		add_event(EVENTLIST *elist, int type, int seconds, int respawn, void (*handler)(void *, int), void *user);
void		add_respawn(EVENTLIST *elist, EVENTLIST *respawn);
EVENTLIST	*get_event_node(void);
void		free_event_node(EVENTLIST *node);
EVENTLIST	*create_eventlist(void);
void		free_eventlist(EVENTLIST *list);
void		event_clean(EVENTLIST *elist);



#endif
