/* 
** log.c - logging functions
**
** Keith Zaback (krz@wcug.wwu.edu) Apr 98
*/

/* includes */
#include "ipxfury.h"
#include <time.h>
#include <stdio.h>
#include <string.h>
#include <stdarg.h>

/* externs */
extern GLOBALS	ifg;

/* protos */
char		*current_time(void);

#ifdef CURSES_CONSOLE

#ifdef	FURY_LINUX
#include <curses.h>
#endif

#ifdef	FURY_BSD
#include <ncurses.h>
#endif

#define CONSOLE_BUF_SIZE	4096

extern WINDOW	*main_win;
extern WINDOW	*cmd_line; 
char		con_buffer[CONSOLE_BUF_SIZE];

#endif

/*
**	NOTICE - prints some info when not in daemon mode
*/
void notice(char *fmt, ...)
{
	va_list		args;
	
	va_start(args, fmt);

	if( ifg.config.background ) {
		if( ifg.logfile != NULL ) {
			vfprintf(ifg.logfile, fmt, args);
			fflush(ifg.logfile);
		}
	} else { 
	
#ifdef CURSES_CONSOLE
		vsnprintf(con_buffer, (CONSOLE_BUF_SIZE-1), fmt, args);
		waddstr(main_win, con_buffer);
		wrefresh(main_win);
		wrefresh(cmd_line);
#else
		vprintf(fmt, args);
#endif
	}
	
	va_end(args);

}


/*
**	ERRORMSG
*/
void errormsg(int level, char *func, char *fmt, ...)
{
	va_list		args;

	/* do we want to show this? */
	if( level <= ifg.verbose_level ) {
		va_start(args, fmt);
		
		if( ifg.config.background ) {
			if( ifg.logfile != NULL ) {
				fprintf(ifg.logfile, "[%s] %s: ", current_time(), func);	
				vfprintf(ifg.logfile, fmt, args);
				fprintf(ifg.logfile, "\n");
				fflush(ifg.logfile);
			}
		} else {
#ifdef CURSES_CONSOLE
			sprintf(con_buffer, "[%s] %s: ", current_time(), func);
			waddstr(main_win, con_buffer);
			vsnprintf(con_buffer, (CONSOLE_BUF_SIZE-1), fmt, args);
			waddstr(main_win, con_buffer);
			waddstr(main_win, "\n");
			wrefresh(main_win);
			wrefresh(cmd_line);
#else
			/* show the error */
			printf("[%s] %s: ", current_time(), func);	
			vprintf(fmt, args);
			printf("\n");
#endif
		}
		va_end(args);
	}

}


/*
**	LOG - logs something into the logfile
*/
void log(char *fmt, ...)
{
	va_list		args;
	
	/* make sure logfile is valid */
	if( ifg.logfile == NULL )
		return;

	/* do the logging */
	va_start(args, fmt);
	fprintf(ifg.logfile, "[%s] ", current_time());
	vfprintf(ifg.logfile, fmt, args);
	fputc('\n', ifg.logfile);
	fflush(ifg.logfile);
	va_end(args);
	
	/* done */
}



/*
**	CURRENT_TIME
*/
char *current_time()
{
	static char	timestr[12];
	char		temp[32];
	time_t		now;
	
	time(&now);
	strcpy(temp, ctime(&now));
	strncpy(timestr, temp+11, 8);
	timestr[8] = 0x00;
	return(timestr);
}

